@@ -1,4 +1,4 @@
-# Copyright 2018 John Reese
+# Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 
 """
@@ -163,6 +163,20 @@ async def list(itr: AnyIterable[T]) -> List[T]:
     return [item async for item in iter(itr)]
 
 
+async def tuple(itr: AnyIterable[T]) -> Tuple[T, ...]:
+    """
+    Consume a mixed iterable and return a tuple of items in order.
+
+    Example::
+
+        await tuple(range(5))
+        -> (0, 1, 2, 3, 4)
+
+    """
+    # Suboptimal, but tuple can't be created from AsyncIterable directly.
+    return builtins.tuple(await list(itr))
+
+
 async def set(itr: AnyIterable[T]) -> Set[T]:
     """
     Consume a mixed iterable and return a set of items.
@@ -229,7 +243,7 @@ async def max(itr: AnyIterable[Orderable], **kwargs: Any) -> Any:
 
     Example::
 
-        await min(range(5))
+        await max(range(5))
         -> 4
 
     """
@@ -327,7 +341,7 @@ async def min(itr: AnyIterable[Orderable], **kwargs: Any) -> Any:
     return value
 
 
-async def sum(itr: AnyIterable[T], start: T = None) -> T:
+async def sum(itr: AnyIterable[T], start: Optional[T] = None) -> T:
     """
     Compute the sum of a mixed iterable, adding each value with the start value.
 
@@ -420,4 +434,4 @@ async def zip(*itrs: AnyIterable[Any]) -> AsyncIterator[Tuple[Any, ...]]:
         )
         if builtins.any(isinstance(v, AnyStop) for v in values):
             break
-        yield values
+        yield builtins.tuple(values)
